@@ -18,6 +18,11 @@ use MooseX::StrictConstructor;
 
 with 'Fey::Role::ColumnLike';
 
+with 'Fey::Role::MakesAliasObjects' =>
+    { self_param  => 'column',
+      alias_class => 'Fey::Column::Alias',
+    };
+
 has 'id' =>
     ( is         => 'ro',
       lazy_build => 1,
@@ -129,15 +134,6 @@ sub _clone
 
 sub is_alias { return 0 }
 
-sub alias
-{
-    my $self = shift;
-
-    my %p = @_ == 1 ? ( alias_name => $_[0] ) : @_;
-
-    return Fey::Column::Alias->new( column => $self, %p );
-}
-
 sub sql
 {
     my $self = shift;
@@ -322,8 +318,8 @@ Returns a unique identifier for the column.
 
 =head1 ROLES
 
-This class does the L<Fey::Role::ColumnLike> and L<Fey::Role::Named>
-roles.
+This class does the L<Fey::Role::ColumnLike>, L<Fey::Role::MakesAliasObjects>,
+and L<Fey::Role::Named> roles.
 
 =head1 AUTHOR
 
