@@ -7,11 +7,6 @@ use warnings;
 # may not be quoting properly for a given DBMS, we will still generate
 # unique ids, and that's all that matters.
 
-sub isa
-{
-    return 1 if $_[1] eq 'DBI::db';
-}
-
 sub quote_identifier
 {
     shift;
@@ -70,7 +65,7 @@ See L<Fey> for details on how to report bugs.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2008 Dave Rolsky, All Rights Reserved.
+Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
