@@ -5,7 +5,15 @@ use warnings;
 
 use Moose::Role;
 
-requires 'bind_params';
+has '_bind_params' =>
+    ( metaclass => 'Collection::Array',
+      is        => 'ro',
+      isa       => 'ArrayRef',
+      default   => sub { [] },
+      provides  => { push => '_add_bind_param',
+                   },
+      init_arg  => undef,
+    );
 
 has 'auto_placeholders' =>
     ( is      => 'ro',
@@ -13,6 +21,13 @@ has 'auto_placeholders' =>
       default => 1,
     );
 
+# This needs to be a method and not a provides accessor so it can be
+# excluded by classes which need to exclude it.
+sub bind_params
+{
+    return @{ $_[0]->_bind_params() };
+}
+
 no Moose::Role;
 
 1;
@@ -38,6 +53,10 @@ parameters.
 
 This role provides the following methods:
 
+=head2 $query->bind_params()
+
+Returns the bind params associated with the query.
+
 =head2 $query->auto_placeholders()
 
 This attribute determines whether values are automatically turned into
@@ -53,7 +72,7 @@ See L<Fey> for details on how to report bugs.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2008 Dave Rolsky, All Rights Reserved.
+Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
