@@ -3,19 +3,15 @@ package Fey::SQL::Where;
 use strict;
 use warnings;
 
+use Fey::Types;
+
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
 
-with 'Fey::Role::SQL::HasBindParams',
-     'Fey::Role::SQL::HasWhereClause';
+with 'Fey::Role::SQL::HasWhereClause';
 
-sub bind_params
-{
-    my $self = shift;
-
-    return $self->_where_clause_bind_params();
-}
+with 'Fey::Role::SQL::HasBindParams' => { excludes => 'bind_params' };
 
 no Moose;
 
@@ -74,7 +70,7 @@ See L<Fey> for details on how to report bugs.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2008 Dave Rolsky, All Rights Reserved.
+Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
